.. role:: hidden
    :class: hidden-section

ax.exceptions
=============

.. automodule:: ax.exceptions
.. currentmodule:: ax.exceptions


Constants
~~~~~~~~~

.. automodule:: ax.exceptions.constants
    :members:
    :undoc-members:
    :show-inheritance:


Core
~~~~

.. automodule:: ax.exceptions.core
    :members:
    :undoc-members:
    :show-inheritance:

Data
~~~~

.. automodule:: ax.exceptions.data_provider
    :members:
    :undoc-members:
    :show-inheritance:

Generation Strategy
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.exceptions.generation_strategy
    :members:
    :undoc-members:
    :show-inheritance:

Model
~~~~~

.. automodule:: ax.exceptions.model
    :members:
    :undoc-members:
    :show-inheritance:

Storage
~~~~~~~

.. automodule:: ax.exceptions.storage
    :members:
    :undoc-members:
    :show-inheritance:
